Configuring Clients
===================

Xandikos supports ``auto-discovery`` of DAV collections (i.e. calendars or
addressbooks). Most clients today do as well, but there are some exceptions.

This section contains basic instructions on how to use various clients with Xandikos.
Please do send us patches if your favourite client is missing.

Evolution
---------

Select "CardDAV" (address books) or "CalDAV" (calendars) as the type when
adding a new account.

Simplify provide the root URL of your Xandikos instance. Hit the "Find
Addressbooks" or "Find Calenders" button and Evolution will prompt for
credentials and show you a list of all relevant calendars or addressbooks.

DAVx5
--------

vdirsyncer
----------

sogo connector for Icedove/Thunderbird
--------------------------------------

caldavzap/carddavmate
---------------------

pycardsyncer
------------

akonadi
-------

CalDAV-Sync
-----------

CardDAV-Sync
------------

Calendarsync
------------

AgendaV
-------

CardBook
--------

Tasks
-----

Apple iOS
---------
